/**!
   * mongodash v1.1.1
   * https://github.com/VaclavObornik/mongodash.git
   *
   * Copyright (c) 2021 Václav Oborník
   * Released under the MIT license
   */
  "use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createContinuousLock = void 0;
function createContinuousLock(collection, documentId, lockProperty, lockTime, onError) {
    let taskInProgress = true;
    let prolongLockTimeoutId = null;
    let lastProlongPromise = Promise.resolve(); // all errors have to be suppressed
    function scheduleLockProlong() {
        prolongLockTimeoutId = setTimeout(() => {
            prolongLockTimeoutId = null;
            lastProlongPromise = (async () => {
                try {
                    // debug('performing lock prolong');
                    await collection.updateOne({ _id: documentId }, { $set: { lockedTill: new Date(Date.now() + lockTime) } });
                }
                catch (err) {
                    // debug('Error during task prolong', err);
                    onError(err);
                }
                finally {
                    if (taskInProgress) {
                        // debug('scheduling next lock prolong');
                        scheduleLockProlong();
                    }
                }
            })();
        }, lockTime / 5);
    }
    scheduleLockProlong();
    /** Should never throw! */
    return async () => {
        taskInProgress = false; // prevent next scheduling
        if (prolongLockTimeoutId) {
            clearTimeout(prolongLockTimeoutId);
        }
        await lastProlongPromise;
    };
}
exports.createContinuousLock = createContinuousLock;
//# sourceMappingURL=createContinuousLock.js.map